@@ -2,8 +2,8 @@
 use strict;
 use warnings;
 package Test::Fatal;
-BEGIN {
-  $Test::Fatal::VERSION = '0.006';
+{
+  $Test::Fatal::VERSION = '0.13';
 }
 # ABSTRACT: incredibly simple helpers for testing code with exceptions
 
@@ -17,18 +17,18 @@ our @EXPORT    = qw(exception);
 our @EXPORT_OK = qw(exception success dies_ok lives_ok);
 
 
-sub exception (&;@) {
+sub exception (&) {
   my $code = shift;
 
   return try {
     $code->();
     return undef;
-  } catch( sub {
+  } catch {
     return $_ if $_;
 
     my $problem = defined $_ ? 'false' : 'undef';
     Carp::confess("$problem exception caught by Test::Fatal::exception");
-  }, @_);
+  };
 }
 
 
